@@ -3,9 +3,10 @@ import typing
 from functools import singledispatch as _singledispatch
 from typing import ClassVar, Optional
 
-from astroid import as_string, decorators, util
+from astroid import decorators, util
 from astroid.exceptions import AstroidError, InferenceError, UseInferenceDefault
 from astroid.manager import AstroidManager
+from astroid.nodes.as_string import AsStringVisitor
 from astroid.nodes.const import OP_PRECEDENCE
 
 
@@ -496,13 +497,9 @@ class NodeNG:
     def eq(self, value):
         return False
 
-    def as_string(self):
-        """Get the source code that this node represents.
-
-        :returns: The source code.
-        :rtype: str
-        """
-        return as_string.to_code(self)
+    def as_string(self) -> str:
+        """Get the source code that this node represents."""
+        return AsStringVisitor()(self)
 
     def repr_tree(
         self,
