@@ -16,8 +16,8 @@
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Vilnis Termanis <vilnis.termanis@iotics.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 doranid <ddandd@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
@@ -35,7 +35,7 @@ from typing import Generator, Optional
 
 from astroid import arguments, bases
 from astroid import context as contextmod
-from astroid import decorators, helpers, node_classes, nodes, util
+from astroid import decorators, helpers, nodes, util
 from astroid.const import Context
 from astroid.exceptions import (
     AstroidIndexError,
@@ -44,6 +44,7 @@ from astroid.exceptions import (
     InferenceError,
     NoDefault,
 )
+from astroid.nodes import node_classes
 
 if sys.version_info >= (3, 8):
     from typing import Literal
